summaryrefslogtreecommitdiffstats
path: root/python/mozbuild/mozbuild/vendor/vendor_rust.py
diff options
context:
space:
mode:
Diffstat (limited to 'python/mozbuild/mozbuild/vendor/vendor_rust.py')
-rw-r--r--python/mozbuild/mozbuild/vendor/vendor_rust.py9
1 files changed, 5 insertions, 4 deletions
diff --git a/python/mozbuild/mozbuild/vendor/vendor_rust.py b/python/mozbuild/mozbuild/vendor/vendor_rust.py
index 15b644cf99..d81f344f32 100644
--- a/python/mozbuild/mozbuild/vendor/vendor_rust.py
+++ b/python/mozbuild/mozbuild/vendor/vendor_rust.py
@@ -47,9 +47,9 @@ CARGO_CONFIG_TEMPLATE = """\
# Take advantage of the fact that cargo will treat lines starting with #
# as comments to add preprocessing directives. This file can thus by copied
# as-is to $topsrcdir/.cargo/config with no preprocessing to be used there
# (for e.g. independent tasks building rust code), or be preprocessed by
# the build system to produce a .cargo/config with the right content.
#define REPLACE_NAME {replace_name}
#define VENDORED_DIRECTORY {directory}
# We explicitly exclude the following section when preprocessing because
@@ -275,6 +275,7 @@ Please commit or stash these changes before vendoring, or re-run with `--ignore-
"ISC",
"MIT",
"MPL-2.0",
+ "Unicode-3.0",
"Unicode-DFS-2016",
"Unlicense",
"Zlib",
@@ -846,7 +847,7 @@ license file's hash.
output = res.stdout.decode("UTF-8")
# Get the snippet of configuration that cargo vendor outputs, and
# update .cargo/config with it.
# XXX(bug 1576765): Hopefully do something better after
# https://github.com/rust-lang/cargo/issues/7280 is addressed.
config = "\n".join(
@@ -880,7 +881,7 @@ license file's hash.
mozpath.normsep(os.path.normcase(self.topsrcdir)),
)
- cargo_config = os.path.join(self.topsrcdir, ".cargo", "config.in")
+ cargo_config = os.path.join(self.topsrcdir, ".cargo", "config.toml.in")
with open(cargo_config, "w", encoding="utf-8", newline="\n") as fh:
fh.write(
CARGO_CONFIG_TEMPLATE.format(
@@ -47,9 +47,9 @@ CARGO_CONFIG_TEMPLATE = """\
# Take advantage of the fact that cargo will treat lines starting with #
# as comments to add preprocessing directives. This file can thus by copied
-# as-is to $topsrcdir/.cargo/config with no preprocessing to be used there
+# as-is to $topsrcdir/.cargo/config.toml with no preprocessing to be used there
# (for e.g. independent tasks building rust code), or be preprocessed by
@@ -47,9 +47,9 @@ CARGO_CONFIG_TEMPLATE = """\
# (for e.g. independent tasks building rust code), or be preprocessed by
-# the build system to produce a .cargo/config with the right content.
+# the build system to produce a .cargo/config.toml with the right content.
#define REPLACE_NAME {replace_name}
#define VENDORED_DIRECTORY {directory}
@@ -846,7 +847,7 @@ license file's hash.
output = res.stdout.decode("UTF-8")
# Get the snippet of configuration that cargo vendor outputs, and
- # update .cargo/config with it.
+ # update .cargo/config.toml with it.
# XXX(bug 1576765): Hopefully do something better after
# https://github.com/rust-lang/cargo/issues/7280 is addressed.